@@ -12,7 +12,10 @@ BEGIN
 use Sub::Exporter -setup => { exports => [ qw() ] } ;
 
 use vars qw ($VERSION @ISA @EXPORT_OK %EXPORT_TAGS);
-$VERSION  = '0.06' ;
+$VERSION     = 0.01;
+
+#~ use version ;
+#~ our $VERSION  = qv('0.01') ;
 }
 
 #-------------------------------------------------------------------------------------------------------------------------------
@@ -25,7 +28,6 @@ Readonly my $EMPTY_STRING => q{} ;
 use Carp qw(carp croak confess) ;
 
 use  Lexical::Persistence ;
-use IO::String ;
 
 #-------------------------------------------------------------------------------------------------------------------------------
 
@@ -49,9 +51,6 @@ POD::Tested - Test the code in your POD and generates POD.
 
 This module lets you write POD documents that are testable. It also let's you generate pod sections dynamically.
 
-Any verbatim section (indented section) is considered part of the POD and the code to be tested. See the I<not_tested>
-tag for verbatim sections that are not code.
-
 =head1 DOCUMENTATION
 
 I wrote this module because I wanted a mechanism to verify the code I write in my POD. Code changes, output
@@ -76,13 +75,13 @@ module's documentation.
 
 Let's run the above POD through B<pod_tested.pl>.
 
-	$> perl pod_tested.pl -input simple.pod -output simple.tested.pod
-	
-	# Generating POD in 'simple.tested.pod'.
+$> perl pod_tested.pl -input simple.pod -output simple.tested.pod
+
+	Generating 'simple.tested.pod'.
 	# No tests run!
 
-	$> cat simple.tested.pod
-	
+$> cat simple.tested.pod
+
 	=head1 cookbook
 	
 	=head2 Simple usage
@@ -99,23 +98,49 @@ Let's run the above POD through B<pod_tested.pl>.
 	
 	Some Text
 	
-	=begin hidden
+	=begin test
 	
 	  my $cc = 'cc' ;
 	  my $expected_cc = 'cc' ;
 	  
-	  is($cc, $expected_cc, 'expected value') ;
+	  is($cc_value, $expected_output) ;
 	
-	=end hidden
+	=end test
 
 Let's run the above POD through B<pod_tested.pl>.
 
 	$> perl pod_tested.pl -input test.pod -output test.tested.pod
-	# output from 'script/test.pod:9':
+	Global symbol "$cc_value" requires explicit package name at 'script/test.pod' line 12, <$in_fh> line 15.
+	Global symbol "$expected_output" requires explicit package name at 'script/test.pod' line 12, <$in_fh> line 15.
+	 at script/pod_tested.pl line 31
+	# Looks like your test died before it could output anything.
+
+Oops! This is a rather common error, copy/pasting code and modifying it for pod.
+Let's correct the pod/code.
+
+	=head1 cookbook
+	
+	=head2 Simple usage
+	
+	Some Text
+	
+	=begin test
+	
+	  my $cc = 'cc' ;
+	  my $expected_cc = 'cc' ;
+	  
+	  is($cc, $expected_cc) ;
+	
+	=end test
+
+Let's run the above POD through B<pod_tested.pl>.
+
+	$> perl pod_tested.pl -input test.pod -output test.tested.pod
+	Output from 'script/test.pod:9':
 	
 	ok 1 - expected value
 	
-	# Generating POD in 'test.tested.pod'.
+	Generating 'test.tested.pod'.
 	1..1
 
 The Generated POD output goes to the output file you specified. You get the test output on your terminal. The POD
@@ -141,6 +166,8 @@ Most often we want to show an example in the POD and verify it.
 	
 	Some text
 	
+	=begin common
+	
 	  use Config::Hierarchical ;
 	   
 	  my $config = new Config::Hierarchical(); 
@@ -152,27 +179,29 @@ Most often we want to show an example in the POD and verify it.
 	  
 	  print "CC = '$cc_value'\n" ;
 	
-	=begin hidden
+	=end common
+	
+	=begin test
 	
 	  my $expected_output = 'gcc' ;
-	  is($cc_value, $expected_output, 'expected value') ;
+	  is($cc_value, $expected_output) ;
 	
-	=end hidden
+	=end test
 	
 	=cut 
 
 Let's run the above POD through B<pod_tested.pl>.
 
 	$> perl pod_tested.pl -input common.pod -output common.tested.pod
-	# output from 'script/common.pod:9':
+	Output from 'script/common.pod:9':
 	
 	CC = 'gcc'
 	
-	# output from 'script/common.pod:24':
+	Output from 'script/common.pod:24':
 	
 	ok 1 - expected value
 	
-	# Generating POD in 'common.tested.pod'.
+	Generating 'common.tested.pod'.
 	1..1
 
 The POD is:
@@ -184,54 +213,33 @@ The POD is:
 	Some text
 	
 	  use Config::Hierarchical ;
-	  
+	
 	  my $config = new Config::Hierarchical();
-	  
+	
 	  $config->Set(NAME => 'CC', VALUE => 'acc') ;
 	  $config->Set(NAME => 'CC', VALUE => 'gcc') ;
-	  
+	
 	  my $cc_value = $config->Get(NAME => 'CC') ;
-	  
+	
 	  print "CC = '$cc_value'\n" ;
 	
 	=cut
 
 =head2 When things go wrong
 
-	=head1 cookbook
-	
-	=head2 Simple usage
-	
-	Some Text
-	
-	=begin hidden
-	
-	  my $cc = 'cc' ;
-	  my $expected_cc = 'cc' ;
-	  
-	  is($cc_value, $expected_output) ;
-	
-	=end hidden
-
-Let's run the above POD through B<pod_tested.pl>.
-
-	$> perl pod_tested.pl -input test.pod -output test.tested.pod
-	Global symbol "$cc_value" requires explicit package name at 'script/test.pod' line 12, <$in_fh> line 15.
-	Global symbol "$expected_output" requires explicit package name at 'script/test.pod' line 12, <$in_fh> line 15.
-	 at script/pod_tested.pl line 31
-	# Looks like your test died before it could output anything.
-
-Oops! This is a rather common error, copy/pasting code and modifying it for pod.
-
 The following pod:
 
 	=head1 HEADER
 	
+	=begin test
+	
 	  my $cc =  ;
 	  my $expected_cc = 'cc' ;
 	  
 	  is($cc, $expected_cc) ;
 	
+	=end test
+	
 	=cut 
 
 produces:
@@ -244,10 +252,14 @@ while:
 
 	=head1 HEADER
 	
+	=begin test
+	
 	  sub error { 1/0 }
 	  
 	  error() ;
 	
+	=end test
+	
 	=cut 
 
 produces:
@@ -262,27 +274,29 @@ produces:
 	
 	Some text
 	
+	=begin common
+	
 	  my $cc_value = 'CC' ;
 	  
 	  print "CC = '$cc_value'\n" ;
 	
-	More text or code examples. 
+	=end common
 	
-	=begin not_tested
+	More text or code examples. The code below will not be tested as it is not in 
+	test section. (With this module you can put all your code in test sections).
 	
-	  # this section is not part of the test but is part of the POD
+	  my $non_testable_code = 1 ;
+	  
+	  # call a sub
 	  
-	  my $non_tested_code = 1 ;
 	  DoSomething() ;
 	
-	=end not_tested
-	
-	=begin hidden
+	=begin test
 	
 	  my $expected_output = 'gcc' ;
 	  is($cc_value, $expected_output) ;
 	
-	=end hidden
+	=end test
 	
 	=cut 
 
@@ -290,73 +304,98 @@ The example above defines a variable in a section and uses it in another section
 
 the output would be:
 
-	# output from 'script/context.pod:7':
+	Output from 'script/context.pod:7':
 	
 	CC = 'CC'
 	
-	# output from 'script/context.pod:20':
+	Output from 'script/context.pod:24':
 	
-	not ok 1
-	#   Failed test at 'script/context.pod' line 21.
+	not ok 1 - expected value
+	#   Failed test at 'script/context.pod' line 25.
 	#          got: 'CC'
 	#     expected: 'gcc'
 	
-	# No POD output will be generated.
-	# Failed tests: 1.
+	Generating 'context.tested.pod'.
 	1..1
 	# Looks like you failed 1 test of 1.
 
-Note that any test fails and the output file already exists, pod_tested will rename the existing file
-so there is little risk for using an invalid file.
-
-=head2 Resetting your context
+The test fails as it should. Note that the POD is generated anyway. it looks like:
 
 	=head1 HEADER
 	
-	=head2 Example 1
+	Some text
 	
 	  my $cc_value = 'CC' ;
 	
+	  print "CC = '$cc_value'\n" ;
+	
+	More text or code examples. The code below will not be tested as it is not in
+	test section. You should put all your code in test sections.
+	
+	  my $non_testable_code = 1 ;
+	
+	  # call a sub
+	
+	  DoSomething() ;
+	
+	=cut
+
+=head2 Reseting your context
+
+	=head1 HEADER
+	
+	= head2 Example 1
+	
+	=begin common
+	
+	  my $cc_value = 'CC' ;
+	
+	=end common
+	
 	<Some explaination about test 1 here>
 	
-	=begin hidden
+	=begin test
 	
 	  is($cc_value, 'CC') ;
 	
-	=end hidden
+	=end test
 	
 	=head2 Example 2
 	
+	=begin common
+	
 	  my $cc_value = 'ABC' ;
 	
+	=end common
+	
 	<Some explaination about test 2 here>
 	
-	=begin hidden
+	=begin test
 	
 	  is($cc_value, 'ABC') ;
 	
-	=end hidden
+	=end test
 	
 	=cut
 
 Running the above pod gives the following output:
 
-	# output from 'script/new_context_error.pod:7':
+	Output from 'script/new_context_error.pod:7':
 	
 	
-	# output from 'script/new_context_error.pod:16':
+	Output from 'script/new_context_error.pod:16':
 	
 	ok 1 - expected value
 	
 	"my" variable $cc_value masks earlier declaration in same scope at 'script/new_context_error.pod' line 24, <$in_fh> line 27.
-	# output from 'script/new_context_error.pod:24':
+	Output from 'script/new_context_error.pod:24':
 	
 	
-	# output from 'script/new_context_error.pod:32':
+	Output from 'script/new_context_error.pod:32':
 	
 	ok 2 - expected value
 	
-	# Generating POD in 'new_context_error.tested.pod'.
+	Generating 'new_context_error.tested.pod'.
 	1..2
 
 Local variables are kept between test sections. What we want is two separate section. This can be achieved with
@@ -366,49 +405,57 @@ B<=for POD::Tested reset>
 	
 	= head2 Example 1
 	
+	=begin common
+	
 	  my $cc_value = 'CC' ;
 	
+	=end common
+	
 	<Some explaination about test 1 here>
 	
-	=begin hidden
+	=begin test
 	
 	  is($cc_value, 'CC') ;
 	
-	=end hidden
+	=end test
 	
 	=head2 Example 2
 	
 	=for POD::Tested reset
 	
+	=begin common
+	
 	  my $cc_value = 'ABC' ;
 	
+	=end common
+	
 	<Some explaination about test 2 here>
 	
-	=begin hidden
+	=begin test
 	
 	  is($cc_value, 'ABC') ;
 	
-	=end hidden
+	=end test
 	
 	=cut
 
 Gives:
 
-	# output from 'script/new_context.pod:7':
+	Output from 'script/new_context.pod:7':
 	
 	
-	# output from 'script/new_context.pod:15':
+	Output from 'script/new_context.pod:15':
 	
 	ok 1 - expected value
 	
-	# output from 'script/new_context.pod:25':
+	Output from 'script/new_context.pod:25':
 	
 	
-	# output from 'script/new_context.pod:33':
+	Output from 'script/new_context.pod:33':
 	
 	ok 2 - expected value
 	
-	# Generating POD in 'new_contex.tested.pod'.
+	Generating 'new_contex.tested.pod'.
 	1..2
 
 and this POD:
@@ -438,6 +485,8 @@ result of some code execution to the POD. We'll use B<generate_pod> to achieve t
 	
 	=head2 Simple usage
 	
+	=begin common
+	
 	  use Config::Hierarchical ;
 	   
 	  my $config = new Config::Hierarchical(); 
@@ -446,31 +495,35 @@ result of some code execution to the POD. We'll use B<generate_pod> to achieve t
 	  my $cc_value = $config->Get(NAME => 'CC') ;
 	  print "CC = '$cc_value'\n" ;
 	
+	=end common
+	
 	Result:
 	
-	=begin hidden
+	=begin test
 	
 	  my $expected_output = 'acc' ;
 	  is($cc_value, $expected_output) ;
 	  
 	  generate_pod("  CC = '$expected_output'\n\n") ;
+	  
+	  use Data::TreeDumper ;  
 	  generate_pod($config->GetHistoryDump(NAME => 'CC')) ;
 	
-	=end hidden
+	=end test
 	
 	=cut
 
 running this gives this output:
 
-	# output from 'script/generate_pod.pod:10':
+	Output from 'script/generate_pod.pod:10':
 	
 	CC = 'acc'
 	
-	# output from 'script/generate_pod.pod:24':
+	Output from 'script/generate_pod.pod:24':
 	
 	ok 1 - expected value
 	
-	# Generating POD in 'generate_pod.tested.pod.pod'.
+	Generating 'generate_pod.tested.pod.pod'.
 	1..1
 
 and the generated POD looks like:
@@ -498,17 +551,17 @@ and the generated POD looks like:
 	
 	=cut
 
-you don't need to copy/paste output from your modules into your POD as you can generate it directly.
+So we don't have to copy/paste output from our modules into our POD as we can generate it directly.
 
 =head2 Using more test modules than the default ones
 
-simply use the modules you need in a B<=begin hidden> section.
+simply use the modules you need in a B<=begin test> section.
 
-	=begin hidden
+	=begin test
 	
 		use Test::Some::Great::Module ;
 	
-	=end hidden
+	= end test
 
 =head1 SUBROUTINES/METHODS
 
@@ -527,49 +580,27 @@ sub new
 
 =head3 Options
 
-You must, in the new sub, pass what your POD source is with one of the following options:
-
-=over 4
-
-=item * FILE_HANDLE
-
-
-=item * FILE
-
-
-=item * STRING
-
-
-=back
-
-
-Other options:
-
 =over 2
 
 =item * VERBOSE  
 
 Set to true to display extra information when parsing and testing POD.
 
-=item * VERBOSE_POD_GENERATION
+=item * COMMON_TAG 
 
-Set to true to display the POD added through B<generate_pod()>.
-
-=item * NOT_TESTED
-
-The tag that is used to declare a section that are not common to the POD and the tests.
+The tag that is used to declare a section common to the POD and the tests.
 
 default value is:
 
-	qr/\s*not_tested/xmi
+	qr/\s*common/xmi
 
-=item * HIDDEN_TAG 
+=item * TEST_TAG 
 
 The tag that is used to declare a test section.
 
 default value is:
 
-	qr/\s*hidden/xmi
+	qr/\s*test/xmi
 
 =item * RESET_TAG 
 
@@ -599,23 +630,23 @@ tested.
 
 =cut
 
-my ($class, @setup_data) = @_ ;
+my ($invocant, @setup_data) = @_ ;
 
-confess 'Invalid constructor call!' if @setup_data % 2 ;
+my $class = ref($invocant) || $invocant ;
+confess 'Invalid constructor call!' unless defined $class ;
 
 my $object = 
 	{
 	BLOCK_START => 0,
 	VERBOSE     => 0,
-	VERBOSE_POD_GENERATION => 0,
 	STATE       => $EMPTY_STRING,
 	CODE        => $EMPTY_STRING,
 	POD         => $EMPTY_STRING,
 	LP          => Lexical::Persistence->new(),
 	
-	NOT_TESTED_TAG  => 	qr/\s*not_tested/sxmi,
-	HIDDEN_TAG    => qr/\s*hidden/sxmi,
-	RESET_TAG   => qr/\s*POD::Tested\s+reset/sxmi,
+	COMMON_TAG  => 	qr/\s*common/xmi,
+	TEST_TAG    => qr/\s*test/xmi,
+	RESET_TAG   => qr/\s*POD::Tested\s+reset/xmi,
 	
 	DEFAULT_TEST_MODULES => <<'EOM',
 use Test::More ;
@@ -650,25 +681,6 @@ bless $object, $class ;
 
 $object->initialize() ;
 
-if(defined $object->{FILE_HANDLE})
-	{
-	$object->parse_from_filehandle($object->{FILE_HANDLE}) ;	
-	}
-elsif(defined $object->{FILE})
-	{
-	$object->parse_from_file($object->{FILE}) ;	
-	}
-elsif(defined $object->{STRING})
-	{
-	$object->parse_from_filehandle( IO::String->new($object->{STRING})) ;	
-	}
-else
-	{
-	croak "Expecting input data through argument 'STRING', 'FILE' or 'FILE_HANDLE'!\n" ;
-	}
-
-$object->RunTestCode() ;
-
 return($object) ;
 }
 
@@ -688,7 +700,6 @@ my ($parser, $command, $paragraph, $line_num, $pod_para) = @_ ;
 chomp($paragraph) ;
 chomp($paragraph) ;
 #~ print "<$command> <$paragraph><$line_num>" ;
-
 for($command)
 	{
 	$_ eq 'for' and do
@@ -705,36 +716,20 @@ for($command)
 		last ;
 		} ;
 		
-	$_ eq 'begin' && do
+	$_ eq 'begin' && ($paragraph =~ $parser->{TEST_TAG} || $paragraph =~ $parser->{COMMON_TAG}) && do
 		{
-		$parser->{STATE} = $paragraph ;
 		$parser->{BLOCK_START} = 0 ;
-		
-		 if($paragraph =~ $parser->{HIDDEN_TAG})
-			{
-			}
-		else
-			{
-			$parser->{POD} .= "=$command $paragraph\n\n" ;
-			}
-			
+		$parser->{STATE} = $paragraph ;
 		last ;
 		} ;
 		
-	$_ eq 'end' && do
+	$_ eq 'end' && ($paragraph =~ $parser->{TEST_TAG} || $paragraph =~ $parser->{COMMON_TAG}) && do
 		{
-		 if($paragraph =~ $parser->{HIDDEN_TAG})
-			{
-			$parser->RunTestCode() ;
-			}
-		else
-			{
-			$parser->{POD} .= "=$command $paragraph\n\n" ;
-			}
-			
-		$parser->{BLOCK_START} = 0 ;
 		$parser->{STATE} = $EMPTY_STRING;
 		
+		EvalInContext($parser->{LP}, $parser->{CODE}, $parser->{VERBOSE}, $parser->input_file(), $parser->{BLOCK_START}) ;
+		
+		$parser->{CODE} = $EMPTY_STRING ;
 		last ;
 		} ;
 		
@@ -746,41 +741,6 @@ return(1) ;
 
 #-------------------------------------------------------------------------------------------------------------------------------
 
-sub RunTestCode
-{
-
-=head2 RunTestCode
-
-Not to be used directly.
-
-=cut
-
-my ($parser) = @_ ;
-
-return(0) if $parser->{CODE} eq $EMPTY_STRING ;
-
-my $input=  $parser->input_file() ;
-$input = $global_current_active_parser->{INPUT} if defined $global_current_active_parser->{INPUT} ;
-
-my $line = $parser->{BLOCK_START} ;
-$line= $global_current_active_parser->{LINE} if defined $global_current_active_parser->{LINE} ;
-
-EvalInContext
-	(
-	$parser->{LP},
-	$parser->{CODE},
-	$parser->{VERBOSE},
-	$input ,
-	$line,
-	) ;
-
-$parser->{CODE} = $EMPTY_STRING ;
-
-return(1) ;
-}
-
-#-------------------------------------------------------------------------------------------------------------------------------
-
 sub verbatim 
 {
 	
@@ -794,18 +754,14 @@ my ($parser, $paragraph, $line_num, $pod_para) = @_;
 
 $parser->{BLOCK_START} =  $line_num if $parser->{BLOCK_START} == 0;
 
-#~ print "verbatim $parser->{STATE} >>$paragraph<<\n" ;
-
-if($parser->{STATE} =~ $parser->{HIDDEN_TAG})
+if($parser->{STATE} =~ $parser->{TEST_TAG})
 	{
 	$parser->{CODE} .= $paragraph ;
 	}
-elsif($parser->{STATE} eq $EMPTY_STRING)
+elsif($parser->{STATE} =~ $parser->{COMMON_TAG})
 	{
 	$parser->{CODE} .= $paragraph ;
 	$parser->{POD} .= $paragraph ;
-	
-	$parser->{BLOCK_START} = 0 ;
 	}
 else
 	{
@@ -828,16 +784,17 @@ Handles POD textblocks. See Pod::Parser for more information.
 
 my ($parser, $paragraph, $line_num, $pod_para) = @_;
 
-#~ print "textblock $parser->{STATE} >>$paragraph<<\n" ;
-
-$parser->RunTestCode() ;
-
 $parser->{BLOCK_START} =  $line_num if $parser->{BLOCK_START} == 0;
 
-if($parser->{STATE} =~ $parser->{HIDDEN_TAG})
+if($parser->{STATE} =~ $parser->{TEST_TAG})
 	{
 	$parser->{CODE} .= $paragraph ;
 	}
+elsif($parser->{STATE} =~ $parser->{COMMON_TAG})
+	{
+	$parser->{CODE} .= $paragraph ;
+	$parser->{POD} .= $paragraph ;
+	}
 else
 	{
 	$parser->{POD} .= $paragraph ;
@@ -855,22 +812,9 @@ sub generate_pod
 
 =cut
 
-my (@pod_snippets) = @_ ;
-
-my ($pod) = join ($EMPTY_STRING, @pod_snippets) ;
-
-if($global_current_active_parser->{VERBOSE_POD_GENERATION})
-	{
-	my ($package, $file_name, $line) = caller() ;
+#~ diag $global_current_active_parser->{STATE} . "\n" ;
 	
-	my $input = '(unknown)';
-	$input = $global_current_active_parser->{FILE} if defined $global_current_active_parser->{FILE} ;
-	$line= $global_current_active_parser->{LINE} if defined $global_current_active_parser->{LINE} ;
-	
-	OutputStrings("# Generating POD at '$input' line $line:\n$pod") ;
-	}
-
-$global_current_active_parser->{POD} .= $pod ;
+$global_current_active_parser->{POD} .= $_[0] ;
 
 return(1) ;
 }
@@ -889,14 +833,12 @@ transformers.
 
 my ($parser) = @_;
 
-Readonly my $PADDING_SIZE => 2 ;
-
 my $pod_end = substr($parser->{POD}, -2, 2) ;
-
 my $amount_of_nl = $pod_end =~ tr[\n][\n] ;
-my $padding_nl = "\n" x ($PADDING_SIZE - $amount_of_nl) ;
+my $padding_nl = "\n" x (2 - $amount_of_nl) ;
 
 return($parser->{POD} . $padding_nl . "=cut\n") ;
+
 }
 
 #-------------------------------------------------------------------------------------------------------------------------------
@@ -912,27 +854,28 @@ Not to be used directly.
 
 my ($lp, $original_code, $verbose, $file, $line) = @_ ;
 
-OutputStrings("# output from '$file:$line':\n\n") ;
+print "Output from '$file:$line':\n\n" ;
 
-if($verbose)
-	{
-	OutputStrings(<<"EOC") ;
+my($code_as_text, $code) = GetWrappedCode($lp, $EMPTY_STRING, $original_code, $EMPTY_STRING, $file, $line) ;
+
+print <<"EOC" if $verbose ;
 running code from '$file:$line':
 
 $original_code
 
 EOC
-	}
-	
-my($code_as_text, $code) = GetWrappedCode($lp, $EMPTY_STRING, $original_code, $EMPTY_STRING, $file, $line) ;
+
+#~ print <<"EOC" ;
+#~ Generated code:
+
+#~ $code_as_text
+
+#~ EOC
 
 eval { $code->() } ;
-if($EVAL_ERROR)
-	{
-	croak $EVAL_ERROR  ;
-	}	
-	
-OutputStrings("\n") ;
+croak $EVAL_ERROR if $EVAL_ERROR ;
+
+print "\n" ;
 
 return(1) ;
 }
@@ -940,7 +883,7 @@ return(1) ;
 #-------------------------------------------------------------------------------------------------------------------------------
 
 sub GetWrappedCode
-{ ## no critic (Subroutines::ProhibitManyArgs)
+{
 	
 =head2 GetWrappedCode
 
@@ -977,24 +920,6 @@ return($subified, $wrapped_code) ;
 
 #-------------------------------------------------------------------------------------------------------------------------------
 
-sub OutputStrings
-{
-
-=head2 OutputStrings
-
-Not to be used directly.
-
-=cut
-
-my (@strings) = @_ ;
-
-print(@strings) or croak $ERRNO ;
-
-return ;
-} 
-
-#-------------------------------------------------------------------------------------------------------------------------------
-
 1 ;
 
 =head1 BUGS AND LIMITATIONS
@@ -1043,8 +968,6 @@ L<http://search.cpan.org/dist/POD-Tested>
 
 L<Test::Inline>
 
-L<Test::Pod::Snippets>
-
 L<Lexical::Persistence>
 
 L<http://chainsawblues.vox.com/library/post/writing-a-perl-repl-part-3---lexical-environments.html>
